==> image-saas-client-0.0.703-sources.jar: com/xforceplus/ultraman/app/imagesaas/controller/CompareTicketCustomsPaymentFeignApi.java <==
package com.xforceplus.ultraman.app.imagesaas.controller;


/**
 * 比对海关缴款书.feign客户端
 *
 * @author ultraman
 * @date 2022-04-06
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.imagesaas.entity.CompareTicketCustomsPayment;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface CompareTicketCustomsPaymentFeignApi {

  /**
   * 通过id查询比对海关缴款书.
   * @param  id
   * @return R
   */
  @GetMapping("/compareTicketCustomsPayment/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增比对海关缴款书.
   * @param compareTicketCustomsPayment 比对海关缴款书.
   * @return R
   */
  @PostMapping("/compareTicketCustomsPayment/add")
  public R save(@RequestBody CompareTicketCustomsPayment compareTicketCustomsPayment);

  /**
   * 修改比对海关缴款书.
   * @param compareTicketCustomsPayment 比对海关缴款书.
   * @return R
   */
  @PostMapping("/compareTicketCustomsPayment/update")
  public R updateById(@RequestBody CompareTicketCustomsPayment compareTicketCustomsPayment);

  /**
   * 通过id删除比对海关缴款书.
   * @param  id
   * @return R
   */
  @DeleteMapping("/compareTicketCustomsPayment/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> image-saas-client-0.1.148-sources.jar: com/xforceplus/ultraman/app/imagesaas/controller/CompareTicketCustomsPaymentFeignApi.java <==
package com.xforceplus.ultraman.app.imagesaas.controller;


/**
 * 比对海关缴款书.feign客户端
 *
 * @author ultraman
 * @date 2023-03-28
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.imagesaas.entity.CompareTicketCustomsPayment;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface CompareTicketCustomsPaymentFeignApi {

  /**
   * 通过id查询比对海关缴款书.
   * @param  id
   * @return R
   */
  @GetMapping("/compareTicketCustomsPayment/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增比对海关缴款书.
   * @param compareTicketCustomsPayment 比对海关缴款书.
   * @return R
   */
  @PostMapping("/compareTicketCustomsPayment/add")
  public R save(@RequestBody CompareTicketCustomsPayment compareTicketCustomsPayment);

  /**
   * 修改比对海关缴款书.
   * @param compareTicketCustomsPayment 比对海关缴款书.
   * @return R
   */
  @PostMapping("/compareTicketCustomsPayment/update")
  public R updateById(@RequestBody CompareTicketCustomsPayment compareTicketCustomsPayment);

  /**
   * 通过id删除比对海关缴款书.
   * @param  id
   * @return R
   */
  @DeleteMapping("/compareTicketCustomsPayment/del/{id}" )
  public R removeById(@PathVariable Long id);

}
